Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Enum UFrameFieldsError

pub enum UFrameFieldsError {
    Malformed(String),
    ValueTooLong {
        field: &'static str,
    },
    Metadata(UFrameMetadataError),
}
Errors returned by the frame metadata field block codec.

Variants



Malformed(String)

The input bytes are not a well-formed field block.



ValueTooLong

A value does not fit its field block length field.

Fields

field: &'static str

Name of the offending field.



Metadata(UFrameMetadataError)

The (decoded or to-be-encoded) metadata violates frame invariants.