pub enum UFrameFieldsError {
Malformed(String),
ValueTooLong {
field: &'static str,
},
Metadata(UFrameMetadataError),
}Expand description
Errors returned by the frame metadata field block codec.
Variants
Malformed(String)
The input bytes are not a well-formed field block.
ValueTooLong
A value does not fit its field block length field.
Metadata(UFrameMetadataError)
The (decoded or to-be-encoded) metadata violates frame invariants.